@@ -1,23 +1,3 @@
-C
-C This code was copied from the R package "FD" in
-C order to avoid an unnecessary dependency
-C (and associated issues with compilation, 
-C  updates, etc.)
-C
-C See R function "maxent" for more details.
-C
-C Laliberte, E., and P. Legendre (2010) A distance-based 
-C framework for measuring functional diversity from 
-C multiple traits. Ecology 91:299-305.
-C
-C Laliberte, E., Legendre, P., and B. Shipley. (2014). 
-C FD: measuring functional diversity from multiple traits, 
-C and other tools for functional ecology. R package 
-C version 1.0-12.
-C 
-C https://CRAN.R-project.org/package=FD
-C 
-
       subroutine itscale5(SXT,ngroups,ntraits,const,
      & prior,prob,entropy,niter,tol,denom) 
 C Implements the Improved Iterative Scaling algorithm of
@@ -40,6 +20,15 @@ C denom are final moments
       double precision gamma1(ntraits),total,test1,tol
       double precision Csums(ntraits),denom(ntraits),unstand(ngroups)
       double precision entropy
+* 2023-10-28_fix this: 
+* itscale5.f:71:13:
+* 
+*    71 |         diff=abs(prob2(i)-prob(i))
+*       |             1
+* Warning: Possible change of value in conversion from 
+* REAL(8) to REAL(4) at (1) [-Wconversion]
+      double precision diff
+* END FIX
       integer niter
       if(ngroups.eq.0)then
        call rexit('Error in itscale5: number of states = 0')
@@ -88,10 +77,7 @@ C loop begins...
        test1=0.
        do i=1,ngroups
         prob2(i)=unstand(i)/total
-c        2018-09-30_NJM:
-c        diff=abs(prob2(i)-prob(i))
-        diff=REAL( abs(prob2(i)-prob(i)), KIND=4 )
-
+        diff=abs(prob2(i)-prob(i))
 C test1 is used to determine convergence.  If the greatest
 C absolute difference between prob estimates in any state
 C across iterations is less that the tolerance, then stop
