@@ -964,7 +964,10 @@ c     2019-07-01: NJM added m, I guess an integer like n
 c     interchanges two vectors.
 c     jack dongarra, 3/11/78.
 c
-      complex(kind=8) m,zx(1),zy(1),ztemp
+c     2023-10-28:
+      complex(kind=8) zx(1),zy(1),ztemp
+      INTEGER            n,m,incx, incy, ix, iy
+
 c
       if(n.le.0)return
       if(incx.eq.1.and.incy.eq.1)go to 20
@@ -972,6 +975,7 @@ c
 c       code for unequal increments or equal increments not equal
 c         to 1
 c
+      
       ix = 1
       iy = 1
       if(incx.lt.0)ix = (-n+1)*incx + 1
@@ -1961,6 +1965,39 @@ c
       end
       
 
+      subroutine  ccopy(n,zx,incx,zy,incy)
+c
+c     copies a vector, x, to a vector, y.
+c     jack dongarra, linpack, 4/11/78.
+c
+      complex(kind=8) zx(1),zy(1)
+      integer i,incx,incy,ix,iy,n
+c
+      if(n.le.0)return
+      if(incx.eq.1.and.incy.eq.1)go to 20
+c
+c        code for unequal increments or equal increments
+c          not equal to 1
+c
+      ix = 1
+      iy = 1
+      if(incx.lt.0)ix = (-n+1)*incx + 1
+      if(incy.lt.0)iy = (-n+1)*incy + 1
+      do 10 i = 1,n
+        zy(iy) = zx(ix)
+        ix = ix + incx
+        iy = iy + incy
+   10 continue
+      return
+c
+c        code for both increments equal to 1
+c
+   20 do 30 i = 1,n
+        zy(i) = zx(i)
+   30 continue
+      return
+      end
+      
 
 ************************************************************************
 * Refactored DZNRM2 code with:
